import { useState } from "react";
import { FiMail, FiEye, FiEyeOff } from "react-icons/fi";

const loginImage = new URL("/public/assets/img/loginadmin.svg", import.meta.url).href;

export default function AdminLogin() {
  const [adminId, setAdminId] = useState("");
  const [password, setPassword] = useState("");
  const [showPassword, setShowPassword] = useState(false);
  const [error, setError] = useState({ adminId: "", password: "", general: "" });

  const validateMerchantId = (id) => /^[A-Z]{4}[0-9]{5}$/.test(id);
  const validatePassword = (pass) => pass.length >= 8;

  const handleSubmit = (e) => {
    e.preventDefault();
    let newErrors = { adminId: "", password: "", general: "" };

    if (!validateMerchantId(adminId)) {
      newErrors.adminId = "Merchant ID must be 4 uppercase letters followed by 5 digits.";
    }
    if (!validatePassword(password)) {
      newErrors.password = "Password must be at least 8 characters long.";
    }

    if (newErrors.adminId || newErrors.password) {
      newErrors.general = "*Incorrect Email or Password !";
      setError(newErrors);
      return;
    }

    setError({ adminId: "", password: "", general: "" });

    alert("Login Successful!");
  };

  return (
    <div className="flex flex-col items-center justify-center h-screen bg-[#D9F6F0] px-6 py-4">
      <h1 className="text-4xl font-font-primary font-semibold text-[#0C4339] mb-6 text-left w-full max-w-[90%]">
        OMPOI - Admin
      </h1>

      <div className="bg-[#1E1E1E] p-6 rounded-lg shadow-lg w-[90%] h-[90%] flex flex-col md:flex-row py-12">
        <div className="hidden md:flex w-1/2 items-center justify-center p-4 min-w-[300px]">
          <img src={loginImage} alt="Login" className="w-[80%] lg:w-[80%] xl:w-[80%]" />
        </div>

      
        <div className="w-[1px] bg-gray-600 hidden md:block"></div>

        <div className="w-full md:w-1/2 flex flex-col items-center justify-start p-6 text-[#6FE7D1]">
          <h2 className="text-3xl md:text-3xl font-font-primary font-semibold text-[#6FE7D1] mb-6">
            Admin Login
          </h2>
       

        <form onSubmit={handleSubmit} className="w- max-w-md">
            <div className="relative mt-6">
              <label className={`absolute -top-3 left-4 px-2 bg-[#1E1E1E] border rounded-md text-sm font-font-primary font-medium 
                ${error.adminId ? "border-[#EEAB4D] text-[#EEAB4D]" : "border-[#6FE7D1] text-[#6FE7D1]"}`}>
                Admin ID
              </label>
              <input
                type="text"
                value={adminId}
                onChange={(e) => setAdminId(e.target.value)}
                placeholder="Enter ID"
                className={`w-96 h-16 px-6 pr-10 border-2 rounded-lg bg-transparent text-white text-lg shadow-sm focus:outline-none font-font-primary
                ${error.adminId ? "border-[#EEAB4D] text-[#EEAB4D]" : "border-[#6FE7D1] text-white"}`}
              />
              <FiMail 
                className="absolute right-4 top-1/2 transform -translate-y-1/2 text-xl transition-colors duration-200"
                style={{ color: error.adminId ? "#EEAB4D" : "#6FE7D1" }} 
              />
            </div>
            <div className="relative mt-12">
              <label className={`absolute -top-3 left-4 px-2 bg-[#1E1E1E] border rounded-md text-sm font-font-primary font-medium 
                ${error.password ? "border-[#EEAB4D] text-[#EEAB4D]" : "border-[#6FE7D1] text-[#6FE7D1]"}`}>
                Password
              </label>
              <input
                type={showPassword ? "text" : "password"}
                value={password}
                onChange={(e) => setPassword(e.target.value)}
                placeholder="Enter your password"
                className={`appearance-none w-full h-14 px-4 pr-10 border-2 rounded-lg bg-transparent text-white text-lg shadow-sm focus:outline-none font-font-primary
                ${error.password ? "border-[#EEAB4D] text-[#EEAB4D]" : "border-[#6FE7D1] text-white"}`}
              />
              {showPassword ? (
                <FiEyeOff 
                  className="absolute right-4 top-1/2 transform -translate-y-1/2 text-xl transition-colors duration-200 cursor-pointer font-font-primary"
                  style={{ color: error.password ? "#EEAB4D" : "#6FE7D1" }}
                  onClick={() => setShowPassword(!showPassword)}
                />
              ) : (
                <FiEye 
                  className="absolute right-4 top-1/2 transform -translate-y-1/2 text-xl transition-colors duration-200 cursor-pointer"
                  style={{ color: error.password ? "#EEAB4D" : "#6FE7D1" }}
                  onClick={() => setShowPassword(!showPassword)}
                />
              )}
            </div>
            <div className="flex justify-between items-center mt-6">
              <a href="#" className="text-[#6FE7D1] hover:underline text-sm font-font-primary font-semibold">
                Forgot Password?
              </a>
              {error.general && (
                <span className="text-[#EEAB4D] text-sm font-semibold  font-font-primary  font-font-primary ">
                  {error.general}
                </span>
              )}
            </div>
            <div className="mt-12 flex justify-center">
              <button 
                type="submit" 
                className="w-48 h-14 text-black font-semibold rounded-full bg-[#6FE7D1] shadow-md hover:bg-[#5CC4AE] transition text-lg font-font-primary font-extrabold">
                Sign In
              </button>
            </div>
            </form>
            </div>

</div>
</div>
  )};